@@ -49,7 +49,6 @@
 
 package com.openexchange.apps.manifests.json;
 
-import java.util.Collection;
 import java.util.Map;
 import com.google.common.collect.ImmutableMap;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
@@ -76,11 +75,6 @@ public class ManifestActionFactory implements AJAXActionServiceFactory {
         this.actions = actions.build();
     }
 
-    @Override
-    public Collection<?> getSupportedServices() {
-        return actions.values();
-    }
-
     @Override
     public AJAXActionService createActionService(String action) throws OXException {
         AJAXActionService actionService = actions.get(action);
