@@ -55,8 +55,6 @@ import java.io.IOException;
 import java.io.OutputStream;
 import java.io.UnsupportedEncodingException;
 import java.util.concurrent.atomic.AtomicReference;
-import java.util.LinkedHashSet;
-import java.util.Set;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 import javax.servlet.ServletException;
@@ -64,7 +62,6 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.json.JSONException;
 import org.json.JSONObject;
-import org.apache.http.HttpStatus;
 import com.openexchange.ajax.SessionServlet;
 import com.openexchange.exception.OXException;
 import com.openexchange.java.Charsets;
@@ -79,11 +76,6 @@ import com.openexchange.tools.session.ServerSessionAdapter;
  */
 public class AppsLoadServlet extends SessionServlet {
 
-	/**
-     * The hardcoded appsuite ui uri limit in characters
-     */
-    private static final int UI_URI_LIMIT = 8190;
-
     private static final long serialVersionUID = -8909104490806162791L;
 
     private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(AppsLoadServlet.class);
@@ -198,50 +190,31 @@ public class AppsLoadServlet extends SessionServlet {
         }
     }
 
-	@Override
-	protected void doGet(final HttpServletRequest req, final HttpServletResponse resp)
-			throws ServletException, IOException {
-	    if (req.getRequestURL().length() > UI_URI_LIMIT) {
-	        LOG.error("Length of request URL exceeds maximum allowed characters of {}.", Integer.valueOf(UI_URI_LIMIT));
-	        writeErrorPage(HttpStatus.SC_REQUEST_URI_TOO_LONG, "Request-URI Too Long", resp);
-	        return;
-	    }
-		ServerSession session = getSessionObject(req, true);
-		String[] modules = Strings.splitByComma(req.getPathInfo());
-		if (null == modules) {
-			return; // no actual files requested
-		}
+    @Override
+    protected void doGet(final HttpServletRequest req, final HttpServletResponse resp) throws ServletException, IOException {
+        ServerSession session = getSessionObject(req, true);
 
-		int length = modules.length;
+        final String[] modules = Strings.splitByComma(req.getPathInfo());
+        if (null == modules) {
+            return; // no actual files requested
+        }
+        final int length = modules.length;
         if (length < 2) {
             return; // no actual files requested
         }
-		// Filter duplicates
-        {
-            Set<String> distinct = new LinkedHashSet<>(length);
-            for (String module : modules) {
-                distinct.add(module);
+        resp.setContentType("text/javascript;charset=UTF-8");
+        ErrorWriter ew = new ErrorWriter(resp, length);
+        for (int i = 1; i < length; i++) {
+            final String module = modules[i].replace(' ', '+');
+            // Module names may only contain letters, digits, '_', '-', '/' and
+            // '.', but not "..".
+            final Matcher m = moduleRE.matcher(module);
+            if (!m.matches()) {
+                final String escapedName = escapeName(module);
+                LOG.debug("Invalid module name: '{}'", escapedName);
+                ew.error(("console.error('Invalid module name detected');\n").getBytes("UTF-8"));
+                continue;
             }
-            modules = distinct.toArray(new String[distinct.size()]);
-        }
-        // Check length again
-		length = modules.length;
-		if (length < 2) {
-			return; // no actual files requested
-		}
-		resp.setContentType("text/javascript;charset=UTF-8");
-		ErrorWriter ew = new ErrorWriter(resp, length);
-		for (int i = 1; i < length; i++) {
-			final String module = modules[i].replace(' ', '+');
-			// Module names may only contain letters, digits, '_', '-', '/' and
-			// '.', but not "..".
-			final Matcher m = moduleRE.matcher(module);
-			if (!m.matches()) {
-				final String escapedName = escapeName(module);
-				LOG.debug("Invalid module name: '{}'", escapedName);
-				ew.error(("console.error('Invalid module name detected');\n").getBytes("UTF-8"));
-				continue;
-			}
 
             // Map module name to file name
             final String format = m.group(1);
@@ -323,13 +296,9 @@ public class AppsLoadServlet extends SessionServlet {
         }
         int[] key = new int[8];
         java.util.Random r = new java.util.Random();
-        for (int j = 0; j < key.length; j++) {
-            key[j] = r.nextInt(256);
-        }
+        for (int j = 0; j < key.length; j++) key[j] = r.nextInt(256);
         char[] obfuscated = moduleName.toCharArray();
-        for (int j = 0; j < obfuscated.length; j++) {
-            obfuscated[j] += key[j % key.length];
-        }
+        for (int j = 0; j < obfuscated.length; j++) obfuscated[j] += key[j % key.length];
         ew.error(("(function(){" +
             "var key = [" + Strings.join(key, ",") + "], name = '" + escapeName(new String(obfuscated)) + "';" +
             "function c(c, i) { return c.charCodeAt(0) - key[i % key.length]; }" +
